@@ -2,8 +2,9 @@
 
 import re
 import argparse
+import sys
 
-__version__ = "2.0.3"
+__version__ = "2.0.4"
 
 dict_nb_solution = dict()
 
@@ -160,7 +161,7 @@ def main(find=False, number=False):
                 )
 
 
-if __name__ == "__main__":
+def run(arg):
     parser = argparse.ArgumentParser(
         prog="Lazy Ghost Hunters",
         description="Find solutions for the game Ghost Hunters.",
@@ -178,5 +179,9 @@ if __name__ == "__main__":
         action="store_true",
     )
     parser.add_argument("-v", "--version", action="version", version=__version__)
-    args = parser.parse_args()
+    args = parser.parse_args(arg)
     main(find=args.find, number=args.number)
+
+
+if __name__ == "__main__":
+    run(sys.argv)
